Learn R Programming

greta (version 0.6.0)

greta_notes_tf_num_error: Retrieve python messages.

Description

These functions retrieve specific python error messages that might come up during greta use.

Usage

greta_notes_tf_num_error()

Arguments

Value

Invisibly returns NULL; called for its side effect of printing the stored message.

Examples

Run this code
if (FALSE) {
greta_notes_tf_num_error()
}

Run the code above in your browser using DataLab