| greta_remove | R Documentation |
A single entry point for removing greta's Python bits, which is useful when
debugging a greta installation and you want to get back to a "clean slate".
Use the what argument to choose how much to remove.
greta_remove(
what = c("all", "env", "miniconda", "uv_cache", "preference", "deps"),
ask = interactive()
)
what |
What to remove. One of:
|
ask |
Ask for confirmation? Default is |
Invisibly, TRUE if anything was removed, otherwise FALSE.
reinstall_greta_deps(), greta_set_python()
## Not run:
# remove everything (nuclear reset)
greta_remove()
# remove only the conda environment
greta_remove("env")
# clear the stored Python preference
greta_remove("preference")
# clear the stored dependency versions
greta_remove("deps")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.