run_optimiser: Dispatch optimisation method to right class

View source: R/optimiser_class.R

run_optimiserR Documentation

Dispatch optimisation method to right class

Description

Should also allow for building other methods in the future

Usage

run_optimiser(self)

Arguments

self

optimiser of class: tf_optimiser, tfp_optimiser, or tf_compat_optimiser.

Value

Invisibly returns NULL; called for its side effect of running the optimiser and updating its internal state.


greta documentation built on July 20, 2026, 5:09 p.m.