Skip to contents

These functions retrieve specific python error messages that might come up during greta use.

Usage

greta_notes_tf_num_error()

Value

Invisibly returns NULL; called for its side effect of printing the stored message.

Examples

if (FALSE) { # \dontrun{
greta_notes_tf_num_error()
} # }