View source: R/install_greta_deps.R
| greta_deps_receipt | R Documentation |
To assist with capturing and sharing python dependencies, we provide a way
to capture the dependencies currently used. Unlike greta_deps_spec(),
the receipt records the versions actually installed and is not
validated against the versions greta supports - so it will faithfully
report, for example, a TensorFlow version newer than greta's supported
range.
greta_deps_receipt()
greta_deps_spec() object
## Not run:
my_deps <- greta_deps_receipt()
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.