Learn R Programming

greta (version 0.6.0)

greta_deps_receipt: Capture greta python dependencies.

Description

To assist with capturing and sharing python dependencies, we provide a way to capture the dependencies currently used. Unlike greta_deps_spec(), the receipt records the versions actually installed and is not validated against the versions greta supports - so it will faithfully report, for example, a TensorFlow version newer than greta's supported range.

Usage

greta_deps_receipt()

Arguments

Value

greta_deps_spec() object

Examples

Run this code
if (FALSE) {
my_deps <- greta_deps_receipt()
}

Run the code above in your browser using DataLab