powered by
These functions retrieve specific python error messages that might come up during greta use.
greta_notes_tf_num_error()
Invisibly returns NULL; called for its side effect of printing the stored message.
NULL
if (FALSE) { greta_notes_tf_num_error() }
Run the code above in your browser using DataLab