To help debug greta installation, you can save all installation output to a single logfile.
Value
nothing - sets an environment variable for use with
install_greta_deps().
To help debug greta installation, you can save all installation output to a single logfile.
nothing - sets an environment variable for use with
install_greta_deps().