Learn R Programming

greta (version 0.6.0)

greta_set_install_logfile: Set logfile path when installing greta

Description

To help debug greta installation, you can save all installation output to a single logfile.

Usage

greta_set_install_logfile(path)

Value

nothing - sets an environment variable for use with install_greta_deps().

Arguments

path

valid path to logfile - should end with .html so you can benefit from the html rendering.