install_greta_deps: Install Python dependencies for greta
Description
This is a helper function to install Python dependencies needed. This
includes Tensorflow version 1.14.0, Tensorflow Probability 0.7.0, and
numpy version 1.16.4. These Python modules will be installed into a
virtual or conda environment, named "greta-env". Note that "virtualenv" is
not available on Windows.
Usage
install_greta_deps(
method = c("auto", "virtualenv", "conda"),
conda = "auto",
timeout = 5,
...
)Arguments
- method
Installation method ("virtualenv" or "conda")
- conda
The path to a conda executable. Use "auto" to allow
reticulate to automatically find an appropriate conda binary. See
Finding Conda for more details.
- timeout
maximum time in minutes until the installation for each
installation component times out and exits. Default is 5 minutes per
installation component.
- ...
Optional arguments, reserved for future expansion.
Examples
Run this codeif (FALSE) {
install_greta_deps()
}
Run the code above in your browser using DataLab