Learn R Programming

greta (version 0.6.0)

run_optimiser: Dispatch optimisation method to right class

Description

Should also allow for building other methods in the future

Usage

run_optimiser(self)

Value

Invisibly returns NULL; called for its side effect of running the optimiser and updating its internal state.

Arguments

self

optimiser of class: tf_optimiser, tfp_optimiser, or tf_compat_optimiser.