powered by
Should also allow for building other methods in the future
run_optimiser(self)
Invisibly returns NULL; called for its side effect of running the optimiser and updating its internal state.
NULL
optimiser of class: tf_optimiser, tfp_optimiser, or tf_compat_optimiser.
tf_optimiser
tfp_optimiser
tf_compat_optimiser