R/greta_stash.R
stash-notes.Rd
These functions retrieve specific python error messages that might come up during greta use.
greta_notes_tf_num_error()
Invisibly returns NULL; called for its side effect of printing the stored message.
NULL
if (FALSE) { # \dontrun{ greta_notes_tf_num_error() } # }