stash-notes: Retrieve python messages.

greta_notes_tf_num_errorR Documentation

Retrieve python messages.

Description

These functions retrieve specific python error messages that might come up during greta use.

Usage

greta_notes_tf_num_error()

Value

Invisibly returns NULL; called for its side effect of printing the stored message.

Examples

## Not run: 
greta_notes_tf_num_error()

## End(Not run)

greta documentation built on July 20, 2026, 5:09 p.m.