These structures can be used to set up more complex models. For
example, scalar parameters can be embedded in a greta array by first
creating a greta array with zeros() or ones(), and then
embedding the parameter value using greta's replacement syntax.
Usage
zeros(...)
ones(...)
greta_array(data = 0, dim = length(data))Arguments
- ...
dimensions of the greta arrays to create
- data
a vector giving data to fill the greta array. Other object types are coerced by
as.vector().- dim
an integer vector giving the dimensions for the greta array to be created.
Details
greta_array is a convenience function to create an R array
with array() and then coerce it to a greta array. I.e. when
passed something that can be coerced to a numeric array, it is equivalent
to as_data(array(data, dim)).
If data is a greta array and
dim is different than dim(data), a reshaped greta array is returned.
This is equivalent to: dim(data) <- dim.